@@ -6,6 +6,7 @@ from .config import SageMakerTrainingConfig
 import json
 import inspect
 import types
+from aws_sagemaker_remote.ecr.images import Images
 
 CHANNEL_HELP = """Input channel [{channel}].
 Set to local path and it will be uploaded to S3 and downloaded to SageMaker.
@@ -15,7 +16,6 @@ Set to S3 path and it will be downloaded to SageMaker.
 CHANNEL_HELP_MODE = """Input channel [{channel}] mode.
 (default: [{default}])
 """
-TRAINING_IMAGE = '683880991063.dkr.ecr.us-east-1.amazonaws.com/columbo-sagemaker-training:latest'
 TRAINING_INSTANCE = 'ml.m5.large'
 TRAINING_ROLE = 'aws-sagemaker-remote-training-role'
 BASE_JOB_NAME = 'training-job'
@@ -108,7 +108,6 @@ def sagemaker_env_args(args: argparse.Namespace, config: SageMakerTrainingConfig
     #print("Updated args: {}".format(new_args))
     return new_args
 
-
 def sagemaker_training_args(
     parser: argparse.ArgumentParser,
     script,
@@ -127,7 +126,9 @@ def sagemaker_training_args(
     checkpoint_dir='output',
     checkpoint_s3='default',
     checkpoint_container=CHECKPOINT_LOCAL_PATH,
-    training_image=TRAINING_IMAGE,
+    training_image=Images.TRAINING.tag,
+    training_image_path=Images.TRAINING.path,
+    training_image_accounts=Images.TRAINING.accounts,
     training_instance=TRAINING_INSTANCE,
     training_role=TRAINING_ROLE,
     enable_sagemaker=True,
@@ -138,7 +139,8 @@ def sagemaker_training_args(
     max_run=60*60*12,
     max_wait=60*60*24,
     env=None,
-    workers=2
+    workers=2,
+    output_json=None
 ):
     r"""
     Configure ``argparse.ArgumentParser`` for training scripts.
@@ -261,6 +263,14 @@ def sagemaker_training_args(
             '--sagemaker-training-image',
             default=training_image,
             help='Docker image for training')
+        group.add_argument(
+            '--sagemaker-training-image-path',
+            default=training_image_path,
+            help='Path to dockerfile if image does not exist')
+        group.add_argument(
+            '--sagemaker-training-image-accounts',
+            default=training_image_accounts,
+            help='Accounts for docker build')
         group.add_argument(
             '--sagemaker-training-role',
             default=training_role,
@@ -297,6 +307,12 @@ def sagemaker_training_args(
             type=int,
             default=max_wait,
             help='Maximum time to wait for spot instances in seconds.')
+        group.add_argument(
+            '--sagemaker-output-json',
+            type=str,
+            default=output_json,
+            help='Output job details to JSON file.')
+            
         sagemaker_training_dependency_args(
             parser=parser, dependencies=config.dependencies)
     sagemaker_training_model_args(parser=parser, model_dir=model_dir)
